@@ -788,9 +788,9 @@ void BrowserWindow::toggleFullScreen()
     }
 
     if (isFullScreen())
-        showNormal();
+        setWindowState(windowState() & ~Qt::WindowFullScreen);
     else
-        showFullScreen();
+        setWindowState(windowState() | Qt::WindowFullScreen);
 }
 
 void BrowserWindow::enterHtmlFullScreen()
@@ -970,6 +970,10 @@ void BrowserWindow::removeActions(const QList<QAction *> &actions)
 void BrowserWindow::addTab()
 {
     m_tabWidget->addView(QUrl(), Qz::NT_SelectedNewEmptyTab, true);
+    m_tabWidget->setCurrentTabFresh(true);
+
+    if (isFullScreen())
+        showNavigationWithFullScreen();
 }
 
 void BrowserWindow::webSearch()
@@ -1035,6 +1039,9 @@ void BrowserWindow::showNavigationWithFullScreen()
 
 void BrowserWindow::hideNavigationWithFullScreen()
 {
+    if (m_tabWidget->isCurrentTabFresh())
+        return;
+
     if (!m_hideNavigationTimer->isActive()) {
         m_hideNavigationTimer->start();
     }
@@ -1068,7 +1075,6 @@ bool BrowserWindow::event(QEvent* event)
             statusBar()->hide();
 
             m_navigationContainer->hide();
-            m_navigationToolbar->setSuperMenuVisible(false);
             m_navigationToolbar->buttonExitFullscreen()->setVisible(true);
         }
         else if (ev->oldState() & Qt::WindowFullScreen && !(windowState() & Qt::WindowFullScreen)) {
@@ -1443,7 +1449,7 @@ bool BrowserWindow::restoreState(const QByteArray &state, int version)
 #ifdef QZ_WS_X11
 int BrowserWindow::getCurrentVirtualDesktop() const
 {
-    if (!QX11Info::isPlatformX11())
+    if (QGuiApplication::platformName() != QL1S("xcb"))
         return 0;
 
     xcb_intern_atom_cookie_t intern_atom;
@@ -1481,7 +1487,7 @@ error:
 
 void BrowserWindow::moveToVirtualDesktop(int desktopId)
 {
-    if (!QX11Info::isPlatformX11())
+    if (QGuiApplication::platformName() != QL1S("xcb"))
         return;
 
     // Don't move when window is already visible or it is first app window
