@@ -1,6 +1,6 @@
 /* ============================================================
 * QupZilla - WebKit based browser
-* Copyright (C) 2010-2014  David Rosca <nowrep@gmail.com>
+* Copyright (C) 2010-2016 David Rosca <nowrep@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -811,7 +811,7 @@ bool QzTools::startExternalProcess(const QString &executable, const QString &arg
 void QzTools::setWmClass(const QString &name, const QWidget* widget)
 {
 #ifdef QZ_WS_X11
-    if (!QX11Info::isPlatformX11())
+    if (QGuiApplication::platformName() != QL1S("xcb"))
         return;
 
     const QByteArray &nameData = name.toUtf8();
@@ -920,15 +920,19 @@ QString QzTools::operatingSystem()
         str.append(" 7");
         break;
 
-    default:
-        OSVERSIONINFO osvi;
-        ZeroMemory(&osvi, sizeof(OSVERSIONINFO));
-        osvi.dwOSVersionInfoSize = sizeof(OSVERSIONINFO);
-        GetVersionEx(&osvi);
+    case QSysInfo::WV_WINDOWS8:
+        str.append(" 8");
+        break;
 
-        if (osvi.dwMajorVersion == 6 &&  osvi.dwMinorVersion == 2) {
-            str.append(" 8");
-        }
+    case QSysInfo::WV_WINDOWS8_1:
+        str.append(" 8.1");
+        break;
+
+    case QSysInfo::WV_WINDOWS10:
+        str.append(" 10");
+        break;
+
+    default:
         break;
     }
 
@@ -936,3 +940,16 @@ QString QzTools::operatingSystem()
 #endif
 }
 
+QString QzTools::cpuArchitecture()
+{
+    return QSysInfo::currentCpuArchitecture();
+}
+
+QString QzTools::operatingSystemLong()
+{
+    const QString arch = cpuArchitecture();
+    if (arch.isEmpty())
+        return QzTools::operatingSystem();
+    return QzTools::operatingSystem() + QSL(" ") + arch;
+}
+
