@@ -123,8 +123,9 @@ void WebView::setPage(WebPage *page)
         return;
     }
 
-    QWebEngineView::setPage(page);
-    m_page = qobject_cast<WebPage*>(page);
+    m_page = page;
+    m_page->setParent(this);
+    QWebEngineView::setPage(m_page);
 
     connect(m_page, SIGNAL(privacyChanged(bool)), this, SIGNAL(privacyChanged(bool)));
 
@@ -222,13 +223,18 @@ void WebView::setZoomLevel(int level)
     applyZoom();
 }
 
+QPoint WebView::mapToViewport(const QPoint &pos) const
+{
+    return page()->mapToViewport(pos);
+}
+
 void WebView::restoreHistory(const QByteArray &data)
 {
     QDataStream stream(data);
     stream >> *history();
 
     // Workaround clearing QWebChannel after restoring history
-    m_page->setupWebChannel();
+    page()->setupWebChannel();
 }
 
 QWidget *WebView::inputWidget() const
@@ -814,7 +820,6 @@ void WebView::createSelectedTextContextMenu(QMenu* menu, const WebHitTestResult
 
 void WebView::createMediaContextMenu(QMenu *menu, const WebHitTestResult &hitTest)
 {
-    m_clickedPos = hitTest.pos();
     bool paused = hitTest.mediaPaused();
     bool muted = hitTest.mediaMuted();
 
@@ -829,10 +834,10 @@ void WebView::createMediaContextMenu(QMenu *menu, const WebHitTestResult &hitTes
 
 void WebView::checkForForm(QAction *action, const QPoint &pos)
 {
-    m_clickedPos = pos;
+    m_clickedPos = mapToViewport(pos);
     QPointer<QAction> act = action;
 
-    page()->runJavaScript(Scripts::getFormData(pos), [this, act](const QVariant &res) {
+    page()->runJavaScript(Scripts::getFormData(m_clickedPos), [this, act](const QVariant &res) {
         const QVariantMap &map = res.toMap();
         if (!act || map.isEmpty())
             return;
@@ -1124,7 +1129,7 @@ void WebView::loadRequest(const LoadRequest &req)
     if (req.operation() == LoadRequest::GetOperation)
         load(req.url());
     else
-        m_page->runJavaScript(Scripts::sendPostData(req.url(), req.data()));
+        page()->runJavaScript(Scripts::sendPostData(req.url(), req.data()));
 }
 
 bool WebView::eventFilter(QObject *obj, QEvent *event)
